@@ -57,10 +57,10 @@ class LinearLabelModel(_AbstractStoichiometricModel):
 
     def __init__(
         self,
-        compounds: List[str] = None,
-        rate_stoichiometries: dict = None,
-        rates: dict = None,
-        meta_info: dict = None,
+        compounds: List[str] | None = None,
+        rate_stoichiometries: dict[str, dict[str, float]] | None = None,
+        rates: dict | None = None,
+        meta_info: dict | None = None,
     ):
         self.isotopomers: Dict[str, List[str]] = {}
         self.base_rates: Dict[str, set[str]] = {}
@@ -232,7 +232,7 @@ class LinearLabelModel(_AbstractStoichiometricModel):
         del self.base_rates[rate_name]
 
     def generate_y0(
-        self, initial_labels: Union[Dict[str, int], Dict[str, List[int]]] = None
+        self, initial_labels: Union[Dict[str, int], Dict[str, List[int]]] | None = None
     ) -> Dict[str, float]:
         """Generate y0 for all isotopomers.
 
