@@ -664,7 +664,9 @@ class Model(_AbstractRateModel):
         include_meta_info
             Whether to include meta info of the model components
         """
-        parameters = self._generate_parameters_source_code(include_meta_info=include_meta_info)
+        parameters, par_fns, derived_pars = self._generate_parameters_source_code(
+            include_meta_info=include_meta_info
+        )
         compounds = self._generate_compounds_source_code(include_meta_info=include_meta_info)
         functions = self._generate_function_source_code()
         module_functions, modules = self._generate_algebraic_modules_source_code(
@@ -673,22 +675,32 @@ class Model(_AbstractRateModel):
         rate_functions, rates = self._generate_rates_source_code(include_meta_info=include_meta_info)
         stoichiometries = self._generate_stoichiometries_source_code()
 
-        model_string = "\n".join(
-            (
-                "import math",
-                "import numpy as np",
-                "from modelbase.ode import Model, Simulator",
-                functions,
-                module_functions,
-                rate_functions,
-                "m = Model()",
-                parameters,
-                compounds,
-                modules,
-                rates,
-                stoichiometries,
-            )
-        )
+        to_export = [
+            "import math",
+            "import numpy as np",
+            "from modelbase.ode import Model, Simulator",
+        ]
+        for i in (
+            functions,
+            module_functions,
+            rate_functions,
+            par_fns,
+        ):
+            if i:
+                to_export.append(i)
+        to_export.append("m = Model()")
+        for i in (
+            parameters,
+            derived_pars,
+            compounds,
+            modules,
+            rates,
+            stoichiometries,
+        ):
+            if i:
+                to_export.append(i)
+
+        model_string = "\n".join(to_export)
         if linted:
             blacked_string = subprocess.run(["black", "-c", model_string], stdout=subprocess.PIPE, check=True)
             return blacked_string.stdout.decode("utf-8")
