@@ -398,15 +398,15 @@ def plot_coefficient_heatmap(
     df: pd.DataFrame,
     title: str,
     cmap: str = "RdBu_r",
-    rows: int = None,
-    columns: int = None,
-    vmax: float = None,
-    vmin: float = None,
-    norm: plt.Normalize = None,
+    rows: list[str] | None = None,
+    columns: list[str] | None = None,
+    vmax: float | None = None,
+    vmin: float | None = None,
+    norm: plt.Normalize | None = None,
     annotate: bool = True,
     colorbar: bool = True,
-    xlabel: str = None,
-    ylabel: str = None,
+    xlabel: str | None = None,
+    ylabel: str | None = None,
     ax: Optional[Axis] = None,
     cax: Optional[Axis] = None,
 ) -> Tuple[Figure, Axis, QuadMesh]:
@@ -443,7 +443,7 @@ def plot_multiple(
     cmap: str = "RdBu_r",
     annotate: bool = True,
     colorbar: bool = True,
-    figsize: Tuple[int, int] = None,
+    figsize: Tuple[int, int] | None = None,
 ) -> Tuple[Figure, Axes]:
     """Plot multiple heatmaps of the response coefficient DataFrames.
 
@@ -493,14 +493,14 @@ def plot_concentration_response_coefficients(
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
     cmap: str = "RdBu_r",
-    rows: int = None,
-    columns: int = None,
-    vmax: float = None,
-    vmin: float = None,
+    rows: list[str] | None = None,
+    columns: list[str] | None = None,
+    vmax: float | None = None,
+    vmin: float | None = None,
     annotate: bool = True,
     colorbar: bool = True,
-    xlabel: str = None,
-    ylabel: str = None,
+    xlabel: str | None = None,
+    ylabel: str | None = None,
     ax: Optional[Axis] = None,
     cax: Optional[Axis] = None,
 ) -> Tuple[Figure, Axis, QuadMesh]:
@@ -542,14 +542,14 @@ def plot_flux_response_coefficients(
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
     cmap: str = "RdBu_r",
-    rows: int = None,
-    columns: int = None,
-    vmax: float = None,
-    vmin: float = None,
+    rows: list[str] | None = None,
+    columns: list[str] | None = None,
+    vmax: float | None = None,
+    vmin: float | None = None,
     annotate: bool = True,
     colorbar: bool = True,
-    xlabel: str = None,
-    ylabel: str = None,
+    xlabel: str | None = None,
+    ylabel: str | None = None,
     ax: Optional[Axis] = None,
     cax: Optional[Axis] = None,
 ) -> Tuple[Figure, Axis, QuadMesh]:
